@@ -1,6 +1,7 @@
 {-  darcs-monitor - Darcs repository monitor
     Copyright © 2007 Antti-Juhani Kaijanaho
     Copyright © 2007 Benjamin Franksen
+    Copyright © 2010 Marco Túlio Gontijo e Silva <marcot@marcot.eti.br>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,6 +20,7 @@
 module EmailPatch (emailPatch,defaultSendmail) where
 
 import Control.Monad.Trans
+import Data.List
 import System.Directory
 import System.Exit
 import System.IO
@@ -34,11 +36,11 @@ defaultSendmail :: String
 defaultSendmail = "/usr/sbin/sendmail"
 
 sendMail :: (MonadConfig m, MonadIO m) =>
-            String -> String -> m Bool
+            [String] -> String -> m Bool
 sendMail recipient text = do
   sendmail <- asks confSendmailPath
   liftIO $ do (inh, outh, errh, ph) <-
-                  runInteractiveProcess sendmail [recipient] Nothing Nothing
+                  runInteractiveProcess sendmail recipient Nothing Nothing
               hClose outh
               hPutStr inh text
               hClose inh
@@ -48,7 +50,7 @@ sendMail recipient text = do
               return (ec == ExitSuccess)
 
 emailPatch :: (MonadConfig m, MonadIO m) =>
-              String -> PatchData -> m Bool
+              [String] -> PatchData -> m Bool
 emailPatch rec pd = do
   diff <- invokeDarcs ["diff"
                       ,"--match=hash " ++ patchHash pd
@@ -79,7 +81,7 @@ emailPatch rec pd = do
                                  else nhe s
                           nhe = showString
                           repl = case k of
-                                   "RECIPIENT" -> nhe rec
+                                   "RECIPIENT" -> nhe recs
                                    "DIFF"      -> he
                                                   $ case maxDiff of
                                                     Just md
@@ -104,6 +106,7 @@ emailPatch rec pd = do
       f hdr (c:r) = showChar c . f hdr r
       f _ [] = id
       text' = f True tmpl
+      recs = concat $ intersperse ", " rec
   let text = case menc of
                Just enc -> showString "MIME-Version: 1.0\n\
                                       \Content-Transfer-Encoding: 8bit\n\
@@ -112,7 +115,7 @@ emailPatch rec pd = do
                            showChar '\n' .
                            text'
                Nothing -> text'
-  liftIO $ putStrLn $ "Sending mail to " ++ rec ++ " about " ++ patchTitle pd
+  liftIO $ putStrLn $ "Sending mail to " ++ recs ++ " about " ++ patchTitle pd
   sendMail rec (text "")
 
 
