@@ -2,6 +2,7 @@
     Copyright © 2007 Antti-Juhani Kaijanaho
     Copyright © 2007 Benja Fallenstein
     Copyright © 2007 Benjamin Franksen
+    Copyright © 2010 Marco Túlio Gontijo e Silva <marcot@marcot.eti.br>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,6 +20,7 @@
 -}
 module Main where
 
+import Control.Arrow
 import Control.Monad
 import Control.Monad.Trans
 import Data.Char
@@ -100,7 +102,8 @@ main = do args <- getArgs
                 HelpOpt -> do putStr (usageInfo (usage pn) options)
                               exitWith ExitSuccess
                     where usage pn_ = "Usage: " ++ pn_ ++
-                                     " [OPTIONS] email RECIPIENT [REPO ...]"
+                                     " [OPTIONS] email RECIPIENT \
+                                     \[email RECIPIENT ...] [REPO ...]"
                 VersionOpt -> do putStrLn $ "darcs-monitor " ++
                                             showVersion version
                                  exitWith ExitSuccess
@@ -141,9 +144,10 @@ main = do args <- getArgs
             (cmd,args'') <- case args' of
                               ["email"] -> err "email requires an argument"
                               ("email":addr:rest) ->
+                                  let (addrs, rest_) = getMoreEmails rest in
                                   return (("emailPatch " ++ addr,
-                                           emailPatch addr),
-                                          rest)
+                                           emailPatch (addr : addrs)),
+                                          rest_)
                               ("print":rest) ->
                                   return (("print",
                                            \p -> liftIO $ print p >> 
@@ -156,6 +160,10 @@ main = do args <- getArgs
                                     _  -> return args''
             mapM_ (processRepo dryRun cmd) repos
 
+getMoreEmails :: [String] -> ([String], [String])
+getMoreEmails ("email" : addr : rest) = first (addr :) $ getMoreEmails rest
+getMoreEmails rest = ([], rest)
+
 err :: (MonadConfig m, MonadIO m) => String -> m a
 err msg = do pn <- asks confProgName
              liftIO $ do hPutStrLn stderr (pn ++ ": " ++ msg)
